@@ -1,5 +1,8 @@
+from datetime import datetime
+
 from django.conf import settings
 from django.core.urlresolvers import reverse
+from django.forms.widgets import DateTimeInput, CheckboxInput
 from django.views.generic import DetailView
 from django.views.generic import ListView
 from django.views.generic import TemplateView
@@ -37,8 +40,20 @@ class DocumentListView(FormView, MongonautViewMixin):
     
     def get_queryset(self):
         self.set_mongonaut_base()
+        self.set_mongoadmin()        
         self.document = getattr(self.models, self.document_name)
         self.queryset = self.document.objects.all()
+        
+        # search. move this to get_queryset        
+        # search. move this to get_queryset
+        q = self.request.GET.get('q')
+        if self.mongoadmin.search_fields and q:
+            params = {}
+            for field in self.mongoadmin.search_fields:
+                search_key = "{field}__icontains".format(field=field)
+                params[search_key] = q
+            self.queryset = self.queryset.filter(**params)
+        
         return self.queryset
         
     def get_initial(self):
@@ -53,6 +68,7 @@ class DocumentListView(FormView, MongonautViewMixin):
         context['app_label'] = self.app_label  
         context['document_name'] = self.document_name
 
+        # Part of upcoming list view form functionality
         if self.queryset.count():
             context['keys'] = ['id',]
             for key in sorted([x for x in self.document._fields.keys() if x != 'id']):
@@ -64,6 +80,10 @@ class DocumentListView(FormView, MongonautViewMixin):
                     continue
                 context['keys'].append(key)
         
+        if self.mongoadmin.search_fields:
+            context['search_field'] = True
+            
+        
         ### Start pagination
         ### Note: 
         ###    Didn't use the Paginator in Django cause mongoengine querysets are 
@@ -175,13 +195,26 @@ class DocumentDetailFormView(FormView, MongonautViewMixin):
             self.form.data = self.request.POST
             self.form.is_bound = True
             if self.form.is_valid():
-                for key, value in self.form.fields.items():
-                    #if hasattr(value, 'document_type_obj') or hasattr(value, 'field'):
-                    if 'readonly' in value.widget.attrs:
+                for key, field in self.form.fields.items():                      
+                    if 'readonly' in field.widget.attrs:
                         # For _id
                         # for ReferenceField - like <class 'articles.models.User'> on Blog                        
                         # For ListField - like 'field': <mongoengine.fields.StringField object at 0x101b51810>,                                
+                        continue                
+                        
+                    if isinstance(field.widget, DateTimeInput):
+                        format = field.widget.format
+                        setattr(self.document, key, datetime.strptime(self.request.POST[key], format))
                         continue
+                        
+                    if isinstance(field.widget, CheckboxInput):
+                        if key in self.request.POST:
+                            setattr(self.document, key, True)
+                        else:
+                            setattr(self.document, key, False)
+                        continue
+
+                    # for strings
                     setattr(self.document, key, self.request.POST[key])
                 self.document.save()
                 # TODO add message for save
